$TITLE ArizonaDrugSmuggler OA4202 2010
$INLINECOM { }
 OPTIONS
   SOLPRINT =     OFF,
   DECIMALS =       1,
   LIMCOL   =      10,
   LIMROW   =      10,
   RESLIM   =      60, {max seconds}
   ITERLIM  =99999999, {max iterations}
   LP       =     COINCBC,
   MIP      =     COINCBC
 ;


$offlisting

$ontext
============================================================================
With the following few lines of code, we are reading in the network specification.
- We read in the set of nodes, from the nodes.csv file
- We read in the set of all arcs, from the arcs_set.csv file
- Finally, we read in the arc data, from the arcs_data.csv file.
  arcdata(i,j,'Distance') will contain the distance on arc i j.
============================================================================
$offtext


SET
    n   nodes  /
$INCLUDE  arizona_nodes.csv
 /;

alias(n,i,j)   {(i,j) is for arc distance and flow}

SET
   arcs(i,j)         arclist  /
$ONDELIM
$INCLUDE  arizona_arcs_set.csv
$OFFDELIM
 /;

table arcdata(i,j,*)
$ONDELIM
$INCLUDE  arizona_arcs_data.csv
$OFFDELIM
;


$ontext
============================================================================
Lets define the typical shortest path LP.

There are two  new things about our definition of the shortest path LP.  First,
we have a parameter 'delay.'  This parameter stores the delay we have on an
arc, if we put up a roadblock there.  This is like the 'd_ij' we talked about
in class, except its the same for all arcs.

Second, our definition includes the parameter xbar(i,j).  We'll use that to
solve for Tihomir's shortest escape route, given a road block plan X.  For now,
we'll just set the xbar(i,j) to zero.  If there is a roadblock on arc i j,
we'll set xbar(i,j) to one.
============================================================================
$offtext

 PARAMETERS
   delay
   xbar(i,j)
 ;

 delay = 0;

 LOOP(arcs(i,j),
   xbar(i,j)=0 ;
 );

 VARIABLE
   Z                 objective function value
 ;

 POSITIVE VARIABLES
   Y(i,j)            flow on arc i j
 ;

 EQUATIONS
   OBJECTIVE
   NETFLOW(n)
 ;

 OBJECTIVE..
$ontext
============================================================================
Fill this with your GAMS code.
============================================================================
$offtext
 ;

 NETFLOW(j)..
$ontext
============================================================================
Fill this with your GAMS code.
============================================================================
$offtext
 ;

 MODEL ShortestPath
 /
   OBJECTIVE
   NETFLOW
 /;

$ontext
============================================================================
Now, lets solve for the drug dealer's shortest path.
============================================================================
$offtext

 SOLVE ShortestPath USING LP MINIMIZING Z;       { find shortest escape route }

$ontext
============================================================================
Lets print the shortest path solution to a file called spstop.out
============================================================================
$offtext


 file out /spstop.out/;
 put out;

 put 'roadblock delay = ', delay /;
 put '****' / ;
 put 'solve ShortestPath' / ;
 put 'drug lord responds with this shortest path:' / ;
 LOOP(arcs(i,j)$(Y.l(i,j)>0),
   put '   transit arc ',i.tl,' -> ', j.tl / ;
 );
 put 'transit cost=',Z.l:10:1 / ;


